==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Input/flac/translations/flac_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="uk">
<defaultcodec></defaultcodec>
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="26"/>
        <source>FLAC Plugin</source>
        <translation>Модуль FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="28"/>
        <source>FLAC Files</source>
        <translation>Файли FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="82"/>
        <source>About FLAC Audio Plugin</source>
        <translation>Про аудіо-модуль FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="83"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Аудіо-модуль FLAC для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="84"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="61"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="67"/>
        <source>bits</source>
        <translation>біт</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>FLAC Info</source>
        <translation>Інформація FLAC</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="183"/>
        <source>-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="86"/>
        <source>Length:</source>
        <translation>Тривалість:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="103"/>
        <source>Sample rate:</source>
        <translation>Частота семплів:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="123"/>
        <source>Channels:</source>
        <translation>Каналів:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="136"/>
        <source>File size:</source>
        <translation>Розмір файлу:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="146"/>
        <source>Bitrate:</source>
        <translation>Бітовая частота:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="173"/>
        <source>Sample width:</source>
        <translation>Ширина кадру:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>Шлях до файлу:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="322"/>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="199"/>
        <source>FLAC Tag</source>
        <translation>FLAC-тег</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="299"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="270"/>
        <source>Track number:</source>
        <translation>Номер треку:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="257"/>
        <source>Year:</source>
        <translation>Рік:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="283"/>
        <source>Genre:</source>
        <translation>Жанр:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="244"/>
        <source>Comment:</source>
        <translation>Коментар:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="231"/>
        <source>Album:</source>
        <translation>Альбом:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="218"/>
        <source>Artist:</source>
        <translation>Виконавець:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="205"/>
        <source>Title:</source>
        <translation>Назва:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="65"/>
        <source>kbps</source>
        <translation>Кб/с</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="68"/>
        <source>KB</source>
        <translation>Кб</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>Інформація</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Input/flac/translations/flac_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="51"/>
        <source>FLAC Plugin</source>
        <translation>Модуль FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="53"/>
        <source>FLAC Files</source>
        <translation>Файли FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="120"/>
        <source>About FLAC Audio Plugin</source>
        <translation>Про аудіо-модуль FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="121"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Аудіо-модуль FLAC для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="122"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="61"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="67"/>
        <source>bits</source>
        <translation>біт</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>FLAC Info</source>
        <translation>Інформація FLAC</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="79"/>
        <location filename="../detailsdialog.ui" line="96"/>
        <location filename="../detailsdialog.ui" line="113"/>
        <location filename="../detailsdialog.ui" line="159"/>
        <location filename="../detailsdialog.ui" line="166"/>
        <location filename="../detailsdialog.ui" line="183"/>
        <source>-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="86"/>
        <source>Length:</source>
        <translation>Тривалість:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="103"/>
        <source>Sample rate:</source>
        <translation>Частота семплів:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="123"/>
        <source>Channels:</source>
        <translation>Каналів:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="136"/>
        <source>File size:</source>
        <translation>Розмір файлу:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="146"/>
        <source>Bitrate:</source>
        <translation>Бітовая частота:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="173"/>
        <source>Sample width:</source>
        <translation>Ширина кадру:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>Шлях до файлу:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="322"/>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="199"/>
        <source>FLAC Tag</source>
        <translation>FLAC-тег</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="299"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="270"/>
        <source>Track number:</source>
        <translation>Номер треку:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="257"/>
        <source>Year:</source>
        <translation>Рік:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="283"/>
        <source>Genre:</source>
        <translation>Жанр:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="244"/>
        <source>Comment:</source>
        <translation>Коментар:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="231"/>
        <source>Album:</source>
        <translation>Альбом:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="218"/>
        <source>Artist:</source>
        <translation>Виконавець:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="205"/>
        <source>Title:</source>
        <translation>Назва:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="65"/>
        <source>kbps</source>
        <translation>Кб/с</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="68"/>
        <source>KB</source>
        <translation>Кб</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>Інформація</translation>
    </message>
</context>
</TS>
